function p = bhw(varargin),

% BHW Create an object used for manipulating Bhatia-Wolf polynomials 
% up to the requested order. 
%
% BHW(Order).  A Bhatia-Wolf object that contains data up to the order requested.
% Here order is the maximum order of radial polynomial.
%
% BHW(nOrder, nAp). Here nOrder is the maximum order of polynomial,
% and nAp is the aperture radius (i.e. the radius of Bhatia-Wolf representation).
%
% Example,
%
%   y = bhw(10);    % 10^th order, aperture radius = 1 
%   y = bhw(10, 2); % 10^th order and aperture radius = 2  

p = init_class;
if (nargin == 0),
    return
end 

p.order     = 0;
p.coord     = 'polar'; % alternative - cartesian
p.aperture  = 1;
p.family    = 'Bhatia-Wolf';
p.type      = 'Iskander et. al.';

if (nargin == 1),
    % only accept order initialization
    p.order     = varargin{1}; nMaxTerm = bhwOrder2Terms(p.order);
    [p.terms(:,1), p.terms(:,2)] = bhwSgl2Dbl((1:1:nMaxTerm)');
    p.coeff     = zeros([ size(p.terms,1) 1]);
    p.coeff(1)  = 1;
elseif (nargin == 2),
    p.aperture = varargin{2};    
else
    error('(ZNK) Unknown invocation.');
end

return


function p = init_class,

 p.family    = [];
 p.type      = [];
 p.order     = [];  % max order  
 p.terms     = [];  % terms (automatically set).
     
 p.coord     = []; % alternative - cartesian
 p.aperture  = [];

 p.coeff     = [];
 p = class(p,'bhw');
return