function p = znk(varargin),

% ZNK Create an object used for manipulating Zernike polynomials 
% up to the requested order. 
%
% ZNK(Order).  A Zernike object that contains data up to the order requested.
% Here order is the maximum order of radial polynomial.
%
% ZNK(nOrder, nAperture). The Order and Aperture radius (i.e. the radius of 
% the Zernike representation).  
%
% Example, 
%
%  y = znk(10);   % 10^th order polynomial and aperture radius = 1
%  y = znk(10,2); % 10^th order polynomial with aperture radius = 2
%


p = init_class;
if (nargin == 0),
   % constructor
   return
end 

p.order     = 0;
p.coord     = 'polar'; % alternative - cartesian
p.aperture  = 1;
p.family    = 'Zernike';
p.type      = 'OSA';

if (nargin == 1),
    % only accept order initialization
    p.order     = varargin{1}; nMaxTerm = znkOrder2Terms(p.order)-1;
    [p.terms(:,1), p.terms(:,2)] = znkSgl2Dbl((0:1:nMaxTerm)');
    p.coeff     = zeros([ size(p.terms,1) 1]);
    p.coeff(1)  = 1;
elseif (nargin == 2),
    p.aperture = varargin{2};    
else
    error('(ZNK) Unknown invocation.');
end

return


function p = init_class,

 p.family    = [];
 p.type      = [];
 p.order     = [];  % max order  
 p.terms     = [];  % terms (automatically set).
     
 p.coord     = []; % alternative - cartesian
 p.aperture  = [];

 p.coeff     = [];
 p = class(p,'znk');
return 









